@@ -1,7 +1,6 @@
-package  # hide from PAUSE
-   P9Y::ProcessTable::Table::Base;
+package P9Y::ProcessTable::Table::Base;
 
-our $VERSION = '1.00_03'; # VERSION
+our $VERSION = '1.05_01'; # VERSION
 
 #############################################################################
 # Modules
